@@ -4,9 +4,10 @@ use warnings;
 use 5.012000;
 use utf8;
 use feature 'unicode_strings';
-use version 0.77; our $VERSION = version->declare('v0.0.1_006');
+use version 0.77; our $VERSION = version->declare('v0.0.1_007');
 use Lingua::LO::NLP::Syllabify;
 use Lingua::LO::NLP::Analyze;
+use Lingua::LO::NLP::Romanize;
 
 =encoding UTF-8
 
@@ -58,7 +59,7 @@ directly.
 
 =head2 new
 
-C<new(option =E<gt> value, ...)>
+    new(option =E<gt> value, ...)
 
 The object constructor currently does nothing; there are no options. However,
 it is likely that there will be in future versions, therefore it is highly
@@ -74,7 +75,7 @@ sub new {
 
 =head2 split_to_syllables
 
-C<my @syllables = $object-E<gt>split_to_syllables(text =E<gt> $text, %options );>
+    my @syllables = $object-E<gt>split_to_syllables(text =E<gt> $text, %options );
 
 Split Lao text into its syllables. Uses a regexp modelled after PHISSAMAY,
 DALALOY and DURRANI: I<Syllabification of Lao Script for Line Breaking>. Takes
@@ -83,12 +84,13 @@ syllables.
 
 =cut
 sub split_to_syllables {
+    shift;  # discard $self for now
     return Lingua::LO::NLP::Syllabify->new(@_)->get_syllables;
 }
 
 =head2 analyze_syllable
 
-C<my $classified = $object-E<gt>analyze_syllable($syllable, %options);>
+    my $classified = $object-E<gt>analyze_syllable($syllable, %options);
 
 Returns a L<Lingua::LO::NLP::Analyze> object that allows you to query
 various syllable properties such as core consonant, tone mark, vowel length and
@@ -96,9 +98,25 @@ tone. See there for details.
 
 =cut
 sub analyze_syllable {
+    shift;  # discard $self for now
     return Lingua::LO::NLP::Analyze->new(@_);
 }
 
+=head2 romanize
+
+    $object-E<gt>romanize($lao, %options);
+
+Returns a romanized version of the text passed in as C<$lao>. See L<Lingua::LO::NLP::Romanize/new> for options. If you don't pass in I<any> options, the defaults are
+C<variant =E<gt> 'PCGN'> and C<hyphenate =E<gt> 1>.
+
+=cut
+sub romanize {
+    my (undef, $lao, %options) = @_;
+    $options{variant} //= 'PCGN';
+    $options{hyphenate} //= 1;
+    return Lingua::LO::NLP::Romanize->new(%options)->romanize( $lao );
+}
+
 =head1 SEE ALSO
 
 L<Lingua::LO::Romanize> is the module that inspired this one. It has some
